dotstow
=======

`GitHub stars <https://github.com/codejamninja/dotstow>`__

   Manage dotfiles with stow

Please ★ this repo if you found it useful ★ ★ ★

Features
--------

-  Group dotfiles into modular units
-  Automatically symlink files
-  Backup dotfiles with git

Installation
------------

.. code:: sh

   pip3 install dotstow

Dependencies
------------

-  `Python 3 <https://www.python.org>`__

Usage
-----

.. code:: sh

   dotstow zsh

Support
-------

Submit an `issue <https://github.com/codejamninja/dotstow/issues/new>`__

Contributing
------------

Review the `guidelines for
contributing <https://github.com/codejamninja/dotstow/blob/master/CONTRIBUTING.md>`__

License
-------

`MIT
License <https://github.com/codejamninja/dotstow/blob/master/LICENSE>`__

`Jam Risser <https://codejam.ninja>`__ © 2018

Changelog
---------

Review the
`changelog <https://github.com/codejamninja/dotstow/blob/master/CHANGELOG.md>`__

Credits
-------

-  `Jam Risser <https://codejam.ninja>`__ - Author

Support on Liberapay
--------------------

A ridiculous amount of coffee ☕ ☕ ☕ was consumed in the process of
building this project.

`Add some fuel <https://liberapay.com/codejamninja/donate>`__ if you’d
like to keep me going!

`Liberapay receiving <https://liberapay.com/codejamninja/donate>`__
`Liberapay patrons <https://liberapay.com/codejamninja/donate>`__
